@@ -3,6 +3,6 @@
 @project: sky-excel->__init__
 @author: 孙楷炎
 @Email: sky4834@163.com
-@synopsis: 该API兼容python2.0版本,但是实际不应该是这样子的,后期会改掉的
-@created_time: 2022/9/28 17:45
-"""
+@synopsis:
+@created_time: 2022/10/11 13:57
+"""
\ No newline at end of file
