@@ -7,7 +7,7 @@
 @created_time: 2022/9/28 18:18
 """
 
-from sky_excel import ExcelExport
+from sky_excel.main.v2.excel_exporter import ExcelExport
 
 global_export_data = [
     {"col_1": "row1", "col_2": "row1", "col_3": "row1", "col_4": "row1"},
@@ -18,12 +18,10 @@ global_export_data = [
     {"col_1": "row6", "col_2": "row1", "col_3": "row1", "col_4": "row1"},
     {"col_1": "row7", "col_2": "row1", "col_3": "row1", "col_4": "row1"},
 ]
-
+#
 # 导出数据测试
-export_instance = ExcelExport(
-    input_dict=global_export_data,
-    excel_templet_path="./templet/templet.xlsx",
-    save_path="D:\\PySet/sky-excel/sky_excel/export/"
-)
-data, err = export_instance.export()
-print(data, err)
+export_instance = ExcelExport(excel_templet_path="./templet/templet.xls")
+data, err = export_instance.additional_write(input_dict=global_export_data)
+
+data, err = export_instance.save(workbook=export_instance.additional_write_wb, save_path="D:\\PySet/sky-excel/sky_excel/export/")
+
